==> neptune_widget_toolkit-2.2.0.25.jar: com/tandbergtv/neptune/widgettoolkit/client/widget/style/StyleNames.java <==
/**
 * StyleNames.java
 * Created on May 18, 2009
 * (C) Copyright TANDBERG Television Ltd.
 */
package com.tandbergtv.neptune.widgettoolkit.client.widget.style;

/**
 * @author Vlada Jakobac
 */
public class StyleNames {

	/**
	 * Style Name for button widgets used to perform actions (search, create, login, add, remove,
	 * group, prev, next)
	 */
	public static final String ACTION_BUTTON_STYLE = "action-button";

	/**
	 * Style Name for button widgets used to perform data loss actions (delete, revert, reset,
	 * cancel)
	 */
	public static final String DATALOSS_BUTTON_STYLE = "dataloss-button";

	/**
	 * Style Name for button widgets used to perform data commit actions (save, roll back)
	 */
	public static final String COMMIT_BUTTON_STYLE = "commit-button";
	
	/**
	 * Style Name for button widgets used to perform actions (search)
	 */
	public static final String DO_BUTTON_STYLE = "do-button";
	
	/**
	 * Style Name for button widgets used to perform state commit actions (activate/inactivate/enable/disable)
	 */
	public static final String CAUTION_BUTTON_STYLE = "caution-button";
	
	/**
	 * Style Name for button widgets used to get to the screen to perform a state commit (create/add/add more)
	 */
	public static final String ACT_TOWARDS_SAVE_BUTTON_STYLE = "act-towards-save-button";
	
	public static final String ENABLE_BUTTON_STYLE="enable-button-style";
	
	public static final String DISABLE_BUTTON_STYLE="disable-button-style";
	
	public static final String PREVIEW_BUTTON_STYLE="preview-button-style";
	
	public static final String ASSOCIATE_BUTTON_STYLE="associate-button-style";
	
	public static final String EXPORT_BUTTON_STYLE="associate-button-style";
	
	public static final String PRINT_BUTTON_STYLE="print-button-style";
	
	public static final String EDIT_BUTTON_STYLE="edit-button-style";
	
	public static final String ACTIVATE_BUTTON_STYLE="activate-button-style";
	public static final String RUN_NOW_BUTTON_STYLE="run-now-button-style";
	public static final String INACTIVATE_BUTTON_STYLE="inactivate-button-style";
	
	
	/** Style for button container */
	public static final String STYLE_CMS_BUTTON_CONTAINER = "cms_button_container";
	
	/** Style for  Normal Grey button  */
	public static final String STYLE_EB_BTN = "ebBtn";
	
	/** Style for color green button  */
	public static final String STYLE_EB_BTN_COLOR_GREEN = "ebBtn_color_green";
	
	/** Style for Displays the icon at the begining of the create button */
	public static final String STYLE_CREATE_BUTTON_ICON = "create_button_icon";
	
	/** Style for Displays the icon at the begining of the delete button */
	public static final String STYLE_DELETE_BUTTON_ICON = "delete_button_icon";
	
	/** Style for Displays the icon at the begining of the search button */
	public static final String STYLE_SEARCH_BUTTON_ICON = "search_button_icon";
	
	/** Style for Displays the icon at the begining of the save button */
	public static final String STYLE_SAVE_BUTTON_ICON = "save_button_icon";
	
	/** Style for Default gwt button */
	public static final String STYLE_GWT_BUTTON = "gwt-Button";
	
	/** Style for resizable button container */
	public static final String STYLE_RESZC_BUTTONS_CONTAINER = "nwt-reszc-buttonsContainer";
	
	/** Style for table list view panel actions container */
	public static final String STYLE_LIST_VIEW_PANEL_ACTIONS = "nwt-TableListViewPanel-actions";
	
	/** Style for Displays the icon at the begining of the tick button  */
	public static final String STYLE_TICK_BUTTON_ICON = "tick_button_icon";
	
	/** Style for Displays the plus icon on the small grey button  */
	public static final String STYLE_PLUS_BUTTON_ICON = "plus_button_icon";

	/** Style for Displays the minus icon on the small grey button  */
	public static final String STYLE_MINUS_BUTTON_ICON = "minus_button_icon";
	
	/** Style for Displays the icon of the add green button */
	public static final String STYLE_ADD_GREEN_BUTTON_ICON = "addgreen_button_icon";
	
	/** Style for Displays the icon at the beginning of the Back to Roles button */
	public static final String STYLE_BACK_TO_ROLES_BUTTON_ICON = "backtolist_button_icon";
	
	/** Style for Displays the icon at the beginning of the add group button */
	public static final String STYLE_ADD_GROUP_BUTTON_ICON = "addgroup_button_icon";

	/** Style for Displays the icon at the beginning of the preview button */
	public static final String STYLE_PREVIEW_BUTTON_ICON = "preview_button_icon";

	/** Style for Displays the icon at the beginning of the add group green plus button */
	public static final String STYLE_ADD_GROUP_GREEN_PLUS_BUTTON_ICON = "addgroup_greenplus_icon";

	/** Style for Displays the enable button */
	public static final String STYLE_ENABLE_BUTTON_ICON = "enable_button_icon";

	/** Style for Displays the disable button */
	public static final String STYLE_DISABLE_BUTTON_ICON = "disable_button_icon";

	/** Style for Displays the rule reorder button */
	public static final String STYLE_REORDER_BUTTON_ICON = "reorder_button_icon";

	/** Style for Displays the next button */
	public static final String STYLE_NEXT_BUTTON_ICON = "next_button_icon";

	/** Style for Displays the icon at the beginning of the previous button */
	public static final String STYLE_PREVIOUS_BUTTON_ICON = "previous_button_icon";

	/** Style for Displays the icon at the beginning of the run now button */
	public static final String STYLE_RUN_NOW_BUTTON_ICON = "runnow_button_icon";

	/** Style for Displays the icon at the beginning of the add row button */
	public static final String STYLE_ADD_ROW_BUTTON_ICON = "addrow_button_icon";

	/** Style for Displays the associate button */
	public static final String STYLE_ASSOCIATE_BUTTON_ICON = "associate_button_icon";

	/** Style for Displays the associate button */
	public static final String STYLE_DISASSOCIATE_BUTTON_ICON = "disassociate_button_icon";

	/** Style for Displays the dark blue button */
	public static final String STYLE_DARK_BLUE_BUTTON_ICON = "ebBtn_color_darkBlue";
	
	/** Style for Displays the copy button */
	public static final String STYLE_COPY_BUTTON_ICON = "copy_button_icon";
	
	/** Style for Displays the icon at the beginning of the delete row button */
	public static final String STYLE_DELETE_ROW_BUTTON_ICON = "deleterow_button_icon";
	
	/** Style for Displays the icon at the beginning of the delete group button */
	public static final String STYLE_DELETE_GROUP_BUTTON_ICON = "deletegroup_button_icon";

	/** Style for Displays the icon at the beginning of the roll back button */
	public static final String STYLE_ROLLBACK_BUTTON_ICON = "rollback_button_icon";
	
	/** Style for Displays the icon at the beginning of the generate report button */
	public static final String STYLE_GENERATE_REPORT_BUTTON_ICON = "genreport_button_icon";

	/** Style for Displays the rule reorder stop button */
	public static final String STYLE_STOP_BUTTON_ICON = "stop_button_icon";
	
	/** Style for Displays the site export button */
	public static final String STYLE_EXPORT_BUTTON_ICON = "export_button_icon";
}

==> neptune_widget_toolkit-2.2.0.43.jar: com/tandbergtv/neptune/widgettoolkit/client/widget/style/StyleNames.java <==
/**
 * StyleNames.java
 * Created on May 18, 2009
 * (C) Copyright TANDBERG Television Ltd.
 */
package com.tandbergtv.neptune.widgettoolkit.client.widget.style;

/**
 * @author Vlada Jakobac
 */
public class StyleNames {

	/**
	 * Style Name for button widgets used to perform actions (search, create, login, add, remove,
	 * group, prev, next)
	 */
	public static final String ACTION_BUTTON_STYLE = "action-button";

	/**
	 * Style Name for button widgets used to perform data loss actions (delete, revert, reset,
	 * cancel)
	 */
	public static final String DATALOSS_BUTTON_STYLE = "dataloss-button";

	/**
	 * Style Name for button widgets used to perform data commit actions (save, roll back)
	 */
	public static final String COMMIT_BUTTON_STYLE = "commit-button";
	
	/**
	 * Style Name for button widgets used to perform actions (search)
	 */
	public static final String DO_BUTTON_STYLE = "do-button";
	
	/**
	 * Style Name for button widgets used to perform state commit actions (activate/inactivate/enable/disable)
	 */
	public static final String CAUTION_BUTTON_STYLE = "caution-button";
	
	/**
	 * Style Name for button widgets used to get to the screen to perform a state commit (create/add/add more)
	 */
	public static final String ACT_TOWARDS_SAVE_BUTTON_STYLE = "act-towards-save-button";
	
	public static final String ENABLE_BUTTON_STYLE="enable-button-style";
	
	public static final String DISABLE_BUTTON_STYLE="disable-button-style";
	
	public static final String PREVIEW_BUTTON_STYLE="preview-button-style";
	
	public static final String ASSOCIATE_BUTTON_STYLE="associate-button-style";
	
	public static final String EXPORT_BUTTON_STYLE="associate-button-style";
	
	public static final String PRINT_BUTTON_STYLE="print-button-style";
	
	public static final String EDIT_BUTTON_STYLE="edit-button-style";
	
	public static final String ACTIVATE_BUTTON_STYLE="activate-button-style";
	public static final String RUN_NOW_BUTTON_STYLE="run-now-button-style";
	public static final String INACTIVATE_BUTTON_STYLE="inactivate-button-style";
	
	
	/** Style for button container */
	public static final String STYLE_CMS_BUTTON_CONTAINER = "cms_button_container";
	
	/** Style for  Normal Grey button  */
	public static final String STYLE_EB_BTN = "ebBtn";
	
	/** Style for color green button  */
	public static final String STYLE_EB_BTN_COLOR_GREEN = "ebBtn_color_green";
	
	/** Style for Displays the icon at the begining of the create button */
	public static final String STYLE_CREATE_BUTTON_ICON = "create_button_icon";
	
	/** Style for Displays the icon at the begining of the delete button */
	public static final String STYLE_DELETE_BUTTON_ICON = "delete_button_icon";
	
	/** Style for Displays the icon at the begining of the search button */
	public static final String STYLE_SEARCH_BUTTON_ICON = "search_button_icon";
	
	/** Style for Displays the icon at the begining of the save button */
	public static final String STYLE_SAVE_BUTTON_ICON = "save_button_icon";
	
	/** Style for Default gwt button */
	public static final String STYLE_GWT_BUTTON = "gwt-Button";
	
	/** Style for resizable button container */
	public static final String STYLE_RESZC_BUTTONS_CONTAINER = "nwt-reszc-buttonsContainer";
	
	/** Style for table list view panel actions container */
	public static final String STYLE_LIST_VIEW_PANEL_ACTIONS = "nwt-TableListViewPanel-actions";
	
	/** Style for Displays the icon at the begining of the tick button  */
	public static final String STYLE_TICK_BUTTON_ICON = "tick_button_icon";
	
	/** Style for Displays the plus icon on the small grey button  */
	public static final String STYLE_PLUS_BUTTON_ICON = "plus_button_icon";

	/** Style for Displays the minus icon on the small grey button  */
	public static final String STYLE_MINUS_BUTTON_ICON = "minus_button_icon";
	
	/** Style for Displays the icon of the add green button */
	public static final String STYLE_ADD_GREEN_BUTTON_ICON = "addgreen_button_icon";
	
	/** Style for Displays the icon at the beginning of the Back to Roles button */
	public static final String STYLE_BACK_TO_ROLES_BUTTON_ICON = "backtolist_button_icon";
	
	/** Style for Displays the icon at the beginning of the add group button */
	public static final String STYLE_ADD_GROUP_BUTTON_ICON = "addgroup_button_icon";

	/** Style for Displays the icon at the beginning of the preview button */
	public static final String STYLE_PREVIEW_BUTTON_ICON = "preview_button_icon";

	/** Style for Displays the icon at the beginning of the add group green plus button */
	public static final String STYLE_ADD_GROUP_GREEN_PLUS_BUTTON_ICON = "addgroup_greenplus_icon";

	/** Style for Displays the enable button */
	public static final String STYLE_ENABLE_BUTTON_ICON = "enable_button_icon";

	/** Style for Displays the disable button */
	public static final String STYLE_DISABLE_BUTTON_ICON = "disable_button_icon";

	/** Style for Displays the rule reorder button */
	public static final String STYLE_REORDER_BUTTON_ICON = "reorder_button_icon";

	/** Style for Displays the next button */
	public static final String STYLE_NEXT_BUTTON_ICON = "next_button_icon";

	/** Style for Displays the icon at the beginning of the previous button */
	public static final String STYLE_PREVIOUS_BUTTON_ICON = "previous_button_icon";

	/** Style for Displays the icon at the beginning of the run now button */
	public static final String STYLE_RUN_NOW_BUTTON_ICON = "runnow_button_icon";

	/** Style for Displays the icon at the beginning of the add row button */
	public static final String STYLE_ADD_ROW_BUTTON_ICON = "addrow_button_icon";

	/** Style for Displays the associate button */
	public static final String STYLE_ASSOCIATE_BUTTON_ICON = "associate_button_icon";

	/** Style for Displays the associate button */
	public static final String STYLE_DISASSOCIATE_BUTTON_ICON = "disassociate_button_icon";

	/** Style for Displays the dark blue button */
	public static final String STYLE_DARK_BLUE_BUTTON_ICON = "ebBtn_color_darkBlue";
	
	/** Style for Displays the copy button */
	public static final String STYLE_COPY_BUTTON_ICON = "copy_button_icon";
	
	/** Style for Displays the icon at the beginning of the delete row button */
	public static final String STYLE_DELETE_ROW_BUTTON_ICON = "deleterow_button_icon";
	
	/** Style for Displays the icon at the beginning of the delete group button */
	public static final String STYLE_DELETE_GROUP_BUTTON_ICON = "deletegroup_button_icon";

	/** Style for Displays the icon at the beginning of the roll back button */
	public static final String STYLE_ROLLBACK_BUTTON_ICON = "rollback_button_icon";
	
	/** Style for Displays the icon at the beginning of the generate report button */
	public static final String STYLE_GENERATE_REPORT_BUTTON_ICON = "genreport_button_icon";

	/** Style for Displays the rule reorder stop button */
	public static final String STYLE_STOP_BUTTON_ICON = "stop_button_icon";
	
	/** Style for Displays the export button */
	public static final String STYLE_EXPORT_BUTTON_ICON = "export_button_icon";
	
	/** Style for displaying the upload button icon */
	public static final String STYLE_UPLOAD_BUTTON_ICON = "upload_button_icon";
	
	/** Style for displaying the print button icon */
	public static final String STYLE_PRINT_BUTTON_ICON = "print_button_icon";
	
	/** Style for displaying the refresh button icon */
	public static final String STYLE_REFRESH_BUTTON_ICON = "refresh_button_icon";	
}
